pyngrok Coverage Report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
pyngrok/__init__.py | 0 | 0 | 0 | 100.00%
pyngrok/conf.py | 34 | 2 | 0 | 94.12%
pyngrok/exception.py | 28 | 0 | 0 | 100.00%
pyngrok/installer.py | 146 | 8 | 4 | 94.52%
pyngrok/ngrok.py | 215 | 26 | 6 | 87.91%
pyngrok/process.py | 207 | 7 | 15 | 96.62%
Total | 630 | 43 | 25 | 93.17%

No items found using the specified filter.